# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.form
from ..container.x_container import XContainer as XContainer_d6fb0cc6
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from ..container.x_index_container import XIndexContainer as XIndexContainer_1c040ebe
from ..container.x_name_container import XNameContainer as XNameContainer_cb90e47
from ..script.x_event_attacher_manager import XEventAttacherManager as XEventAttacherManager_49f80fde

class FormComponents(XContainer_d6fb0cc6, XEnumerationAccess_4bac0ffc, XIndexContainer_1c040ebe, XNameContainer_cb90e47, XEventAttacherManager_49f80fde):
    """
    Service Class

    specifies the capabilities of a collection of FormComponents.
    
    The collection must provide the possibility of adding and removing components by name and by index. The name of a component is not necessarily unique, so the collection must be able to handle duplicate entry names.

    See Also:
        `API FormComponents <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1FormComponents.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.form'
    __ooo_full_ns__: str = 'com.sun.star.form.FormComponents'
    __ooo_type_name__: str = 'service'



__all__ = ['FormComponents']

