# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.deployment.ui
import typing
from abc import abstractmethod
from ...ui.dialogs.x_executable_dialog import XExecutableDialog as XExecutableDialog_450f0fa1
if typing.TYPE_CHECKING:
    from ...awt.x_window import XWindow as XWindow_713b0924

class LicenseDialog(XExecutableDialog_450f0fa1):
    """
    Service Class

    The LicenseDialog is used to display a license text.
    
    **since**
    
        OOo 2.0.4

    See Also:
        `API LicenseDialog <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1deployment_1_1ui_1_1LicenseDialog.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.deployment.ui'
    __ooo_full_ns__: str = 'com.sun.star.deployment.ui.LicenseDialog'
    __ooo_type_name__: str = 'service'

    @abstractmethod
    def create(self, xParent: 'XWindow_713b0924', extensionName: str, licenseText: str) -> None:
        """
        Create a GUI using the specific parent window and focus on the given context.
        """
        ...


__all__ = ['LicenseDialog']

