# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
from enum import IntEnum
from typing import TYPE_CHECKING
from ooo.oenv.env_const import UNO_ENVIRONMENT, UNO_RUNTIME

_DYNAMIC = False
if (not TYPE_CHECKING) and UNO_RUNTIME and UNO_ENVIRONMENT:
    _DYNAMIC = True

if not TYPE_CHECKING and _DYNAMIC:
    from ooo.helper.enum_helper import UnoConstMeta, ConstEnumMeta

    class FieldUnit(metaclass=UnoConstMeta, type_name="com.sun.star.awt.FieldUnit", name_space="com.sun.star.awt"):
        """Dynamic Class. Contains all the constant values of ``com.sun.star.awt.FieldUnit``"""
        pass

    class FieldUnitEnum(IntEnum, metaclass=ConstEnumMeta, type_name="com.sun.star.awt.FieldUnit", name_space="com.sun.star.awt"):
        """Dynamic Enum. Contains all the constant values of ``com.sun.star.awt.FieldUnit`` as Enum values"""
        pass

else:
    from ...lo.awt.field_unit import FieldUnit as FieldUnit

    class FieldUnitEnum(IntEnum):
        """
        Enum of Const Class FieldUnit

        specifies attributes for the MetricField map units.
        
        IMPORTANT: These constants have to be disjunct with constants in util/MeasureUnit.
        """
        FUNIT_NONE = FieldUnit.FUNIT_NONE
        FUNIT_MM = FieldUnit.FUNIT_MM
        FUNIT_CM = FieldUnit.FUNIT_CM
        FUNIT_M = FieldUnit.FUNIT_M
        FUNIT_KM = FieldUnit.FUNIT_KM
        FUNIT_TWIP = FieldUnit.FUNIT_TWIP
        FUNIT_POINT = FieldUnit.FUNIT_POINT
        FUNIT_PICA = FieldUnit.FUNIT_PICA
        FUNIT_INCH = FieldUnit.FUNIT_INCH
        FUNIT_FOOT = FieldUnit.FUNIT_FOOT
        FUNIT_MILE = FieldUnit.FUNIT_MILE
        FUNIT_CUSTOM = FieldUnit.FUNIT_CUSTOM
        FUNIT_PERCENT = FieldUnit.FUNIT_PERCENT
        FUNIT_100TH_MM = FieldUnit.FUNIT_100TH_MM

__all__ = ['FieldUnit', 'FieldUnitEnum']
