# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.script.vba
import typing
from abc import abstractmethod, ABC

class XVBAEventProcessor(ABC):
    """
    Executes VBA event handlers.

    See Also:
        `API XVBAEventProcessor <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1script_1_1vba_1_1XVBAEventProcessor.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.script.vba'
    __ooo_full_ns__: str = 'com.sun.star.script.vba.XVBAEventProcessor'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.script.vba.XVBAEventProcessor'

    @abstractmethod
    def hasVbaEventHandler(self, nEventId: int, aArgs: 'typing.Tuple[object, ...]') -> bool:
        """
        Returns whether a VBA event handler exists.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
        ...
    @abstractmethod
    def processVbaEvent(self, nEventId: int, aArgs: 'typing.Tuple[object, ...]') -> bool:
        """
        Executes a VBA event handler.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
            com.sun.star.util.VetoException: ``VetoException``
        """
        ...

__all__ = ['XVBAEventProcessor']

