# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.xml.input
from abc import abstractmethod
from ...uno.x_interface import XInterface as XInterface_8f010a43

class XNamespaceMapping(XInterface_8f010a43):
    """
    Interface to map XML namespace URI strings to ordinals (URI-id, short uid).

    See Also:
        `API XNamespaceMapping <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1input_1_1XNamespaceMapping.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.xml.input'
    __ooo_full_ns__: str = 'com.sun.star.xml.input.XNamespaceMapping'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.xml.input.XNamespaceMapping'

    @abstractmethod
    def getUidByUri(self, uri: str) -> int:
        """
        Creates a unique ordinal passing an XML namespace URI.
        """
        ...
    @abstractmethod
    def getUriByUid(self, uid: int) -> str:
        """
        Gets the corresponding XML namespace URI passing a uid (created using getUidByUri()).

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
        """
        ...

__all__ = ['XNamespaceMapping']

