# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.awt
import typing
from abc import abstractmethod
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_action_listener import XActionListener as XActionListener_c7560c50

class XFixedHyperlink(XInterface_8f010a43):
    """
    gives access to the text and formatting of a fixed hyperlink field.

    See Also:
        `API XFixedHyperlink <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XFixedHyperlink.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.awt'
    __ooo_full_ns__: str = 'com.sun.star.awt.XFixedHyperlink'
    __ooo_type_name__: str = 'interface'
    __pyunointerface__: str = 'com.sun.star.awt.XFixedHyperlink'

    @abstractmethod
    def addActionListener(self, l: 'XActionListener_c7560c50') -> None:
        """
        registers an event handler for click action event.
        """
        ...
    @abstractmethod
    def getAlignment(self) -> int:
        """
        returns the alignment of the text in the control.
        """
        ...
    @abstractmethod
    def getText(self) -> str:
        """
        returns the text of the control.
        """
        ...
    @abstractmethod
    def getURL(self) -> str:
        """
        returns the url of the control.
        """
        ...
    @abstractmethod
    def removeActionListener(self, l: 'XActionListener_c7560c50') -> None:
        """
        unregisters an event handler for click action event.
        """
        ...
    @abstractmethod
    def setAlignment(self, nAlign: int) -> None:
        """
        sets the alignment of the text in the control.
        """
        ...
    @abstractmethod
    def setText(self, Text: str) -> None:
        """
        sets the text of the control.
        """
        ...
    @abstractmethod
    def setURL(self, URL: str) -> None:
        """
        sets the url of the control.
        """
        ...

__all__ = ['XFixedHyperlink']

