# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.4
# Namespace: com.sun.star.sheet
from ..container.x_enumeration import XEnumeration as XEnumeration_f2180daa

class CellFormatRangesEnumeration(XEnumeration_f2180daa):
    """
    Service Class

    represents an enumeration of equal-formatted cell ranges.

    See Also:
        `API CellFormatRangesEnumeration <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sheet_1_1CellFormatRangesEnumeration.html>`_
    """
    __ooo_ns__: str = 'com.sun.star.sheet'
    __ooo_full_ns__: str = 'com.sun.star.sheet.CellFormatRangesEnumeration'
    __ooo_type_name__: str = 'service'



__all__ = ['CellFormatRangesEnumeration']

